==> MIDITrail-Ver.1.0.1src.zip: MIDITrail/MIDITrail/MTTimeIndicator.h <==
//******************************************************************************
//
// MIDITrail / MTTimeIndicator
//
// ^CCWP[^`NX
//
// Copyright (C) 2010 WADA Masashi. All Rights Reserved.
//
//******************************************************************************

// MEMO:
// uĐĂƂvwĐʂ`悷B

#pragma once

#include <d3d9.h>
#include <d3dx9.h>
#include "SMIDILib.h"
#include "DXPrimitive.h"
#include "MTNoteDesign.h"

using namespace SMIDILib;


//******************************************************************************
// ^CCWP[^`NX
//******************************************************************************
class MTTimeIndicator
{
public:

	//RXgN^^fXgN^
	MTTimeIndicator(void);
	virtual ~MTTimeIndicator(void);

	//
	int Create(LPDIRECT3DDEVICE9 pD3DDevice, SMSeqData* pSeqData);

	//XV
	int Transform(LPDIRECT3DDEVICE9 pD3DDevice, D3DXVECTOR3 camVector);

	//`
	int Draw(LPDIRECT3DDEVICE9 pD3DDevice);

	//
	void Release();

	//t`bN^Co^
	void SetCurTickTime(unsigned long curTickTime);

	//Zbg
	void Reset();

	//݈ʒu擾
	float GetPos();

private:

	DXPrimitive m_Primitive;
	D3DXIMAGE_INFO m_ImgInfo;
	float m_PosStart;
	float m_PosEnd;
	float m_CurPos;
	MTNoteDesign m_NoteDesign;

	unsigned long m_CurTickTime;

	//_obt@\
	struct MTTIMEINDICATOR_VERTEX {
		D3DXVECTOR3 p;	//_W
		D3DXVECTOR3 n;	//@
		DWORD		c;	//fBt[YF
	};

	//_obt@FVFtH[}bg
	DWORD _GetFVFFormat(){ return (D3DFVF_XYZ | D3DFVF_NORMAL | D3DFVF_DIFFUSE); }

	int _CreateVertexOfIndicator(
			MTTIMEINDICATOR_VERTEX* pVertex,
			unsigned long* pIbIndex,
			unsigned long totalTickTime
		);

};

==> MIDITrail-Ver.1.0.3src.zip: MIDITrail/MIDITrail/MTTimeIndicator.h <==
//******************************************************************************
//
// MIDITrail / MTTimeIndicator
//
// ^CCWP[^`NX
//
// Copyright (C) 2010 WADA Masashi. All Rights Reserved.
//
//******************************************************************************

// MEMO:
// uĐĂƂvwĐʂ`悷B

#pragma once

#include <d3d9.h>
#include <d3dx9.h>
#include "SMIDILib.h"
#include "DXPrimitive.h"
#include "MTNoteDesign.h"

using namespace SMIDILib;


//******************************************************************************
// ^CCWP[^`NX
//******************************************************************************
class MTTimeIndicator
{
public:

	//RXgN^^fXgN^
	MTTimeIndicator(void);
	virtual ~MTTimeIndicator(void);

	//
	int Create(LPDIRECT3DDEVICE9 pD3DDevice, const TCHAR* pSceneName, SMSeqData* pSeqData);

	//XV
	int Transform(LPDIRECT3DDEVICE9 pD3DDevice, D3DXVECTOR3 camVector);

	//`
	int Draw(LPDIRECT3DDEVICE9 pD3DDevice);

	//
	void Release();

	//t`bN^Co^
	void SetCurTickTime(unsigned long curTickTime);

	//Zbg
	void Reset();

	//݈ʒu擾
	float GetPos();

private:

	DXPrimitive m_Primitive;
	DXPrimitive m_PrimitiveLine;
	float m_CurPos;
	MTNoteDesign m_NoteDesign;
	bool m_isEnableLine;

	unsigned long m_CurTickTime;

	//_obt@\
	struct MTTIMEINDICATOR_VERTEX {
		D3DXVECTOR3 p;	//_W
		D3DXVECTOR3 n;	//@
		DWORD		c;	//fBt[YF
	};

	//_obt@FVFtH[}bg
	DWORD _GetFVFFormat(){ return (D3DFVF_XYZ | D3DFVF_NORMAL | D3DFVF_DIFFUSE); }

	int _CreatePrimitive(LPDIRECT3DDEVICE9 pD3DDevice);
	int _CreatePrimitiveLine(LPDIRECT3DDEVICE9 pD3DDevice);
	int _CreateVertexOfIndicator(MTTIMEINDICATOR_VERTEX* pVertex, unsigned long* pIbIndex);
	int _CreateVertexOfIndicatorLine(MTTIMEINDICATOR_VERTEX* pVertex);

};
